import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { LexModelsV2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../LexModelsV2Client";
import { DeleteExportRequest, DeleteExportResponse } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DeleteExportCommand}.
 */
export interface DeleteExportCommandInput extends DeleteExportRequest {
}
/**
 * @public
 *
 * The output of {@link DeleteExportCommand}.
 */
export interface DeleteExportCommandOutput extends DeleteExportResponse, __MetadataBearer {
}
declare const DeleteExportCommand_base: {
    new (input: DeleteExportCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteExportCommandInput, DeleteExportCommandOutput, LexModelsV2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: DeleteExportCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteExportCommandInput, DeleteExportCommandOutput, LexModelsV2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Removes a previous export and the associated files stored in an S3
 *          bucket.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { LexModelsV2Client, DeleteExportCommand } from "@aws-sdk/client-lex-models-v2"; // ES Modules import
 * // const { LexModelsV2Client, DeleteExportCommand } = require("@aws-sdk/client-lex-models-v2"); // CommonJS import
 * const client = new LexModelsV2Client(config);
 * const input = { // DeleteExportRequest
 *   exportId: "STRING_VALUE", // required
 * };
 * const command = new DeleteExportCommand(input);
 * const response = await client.send(command);
 * // { // DeleteExportResponse
 * //   exportId: "STRING_VALUE",
 * //   exportStatus: "InProgress" || "Completed" || "Failed" || "Deleting",
 * // };
 *
 * ```
 *
 * @param DeleteExportCommandInput - {@link DeleteExportCommandInput}
 * @returns {@link DeleteExportCommandOutput}
 * @see {@link DeleteExportCommandInput} for command's `input` shape.
 * @see {@link DeleteExportCommandOutput} for command's `response` shape.
 * @see {@link LexModelsV2ClientResolvedConfig | config} for LexModelsV2Client's `config` shape.
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>The service encountered an unexpected condition. Try your request
 *          again.</p>
 *
 * @throws {@link PreconditionFailedException} (client fault)
 *  <p>Your request couldn't be completed because one or more request
 *          fields aren't valid. Check the fields in your request and try
 *          again.</p>
 *
 * @throws {@link ServiceQuotaExceededException} (client fault)
 *  <p>You have reached a quota for your bot. </p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>Your request rate is too high. Reduce the frequency of
 *          requests.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>One of the input parameters in your request isn't valid. Check the
 *          parameters and try your request again.</p>
 *
 * @throws {@link LexModelsV2ServiceException}
 * <p>Base exception class for all service exceptions from LexModelsV2 service.</p>
 *
 * @public
 */
export declare class DeleteExportCommand extends DeleteExportCommand_base {
}
