import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { LexModelsV2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../LexModelsV2Client";
import { DescribeBotReplicaRequest, DescribeBotReplicaResponse } from "../models/models_1";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DescribeBotReplicaCommand}.
 */
export interface DescribeBotReplicaCommandInput extends DescribeBotReplicaRequest {
}
/**
 * @public
 *
 * The output of {@link DescribeBotReplicaCommand}.
 */
export interface DescribeBotReplicaCommandOutput extends DescribeBotReplicaResponse, __MetadataBearer {
}
declare const DescribeBotReplicaCommand_base: {
    new (input: DescribeBotReplicaCommandInput): import("@smithy/smithy-client").CommandImpl<DescribeBotReplicaCommandInput, DescribeBotReplicaCommandOutput, LexModelsV2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: DescribeBotReplicaCommandInput): import("@smithy/smithy-client").CommandImpl<DescribeBotReplicaCommandInput, DescribeBotReplicaCommandOutput, LexModelsV2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Monitors the bot replication status through the UI console.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { LexModelsV2Client, DescribeBotReplicaCommand } from "@aws-sdk/client-lex-models-v2"; // ES Modules import
 * // const { LexModelsV2Client, DescribeBotReplicaCommand } = require("@aws-sdk/client-lex-models-v2"); // CommonJS import
 * const client = new LexModelsV2Client(config);
 * const input = { // DescribeBotReplicaRequest
 *   botId: "STRING_VALUE", // required
 *   replicaRegion: "STRING_VALUE", // required
 * };
 * const command = new DescribeBotReplicaCommand(input);
 * const response = await client.send(command);
 * // { // DescribeBotReplicaResponse
 * //   botId: "STRING_VALUE",
 * //   replicaRegion: "STRING_VALUE",
 * //   sourceRegion: "STRING_VALUE",
 * //   creationDateTime: new Date("TIMESTAMP"),
 * //   botReplicaStatus: "Enabling" || "Enabled" || "Deleting" || "Failed",
 * //   failureReasons: [ // FailureReasons
 * //     "STRING_VALUE",
 * //   ],
 * // };
 *
 * ```
 *
 * @param DescribeBotReplicaCommandInput - {@link DescribeBotReplicaCommandInput}
 * @returns {@link DescribeBotReplicaCommandOutput}
 * @see {@link DescribeBotReplicaCommandInput} for command's `input` shape.
 * @see {@link DescribeBotReplicaCommandOutput} for command's `response` shape.
 * @see {@link LexModelsV2ClientResolvedConfig | config} for LexModelsV2Client's `config` shape.
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>The service encountered an unexpected condition. Try your request
 *          again.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>You asked to describe a resource that doesn't exist. Check the
 *          resource that you are requesting and try again.</p>
 *
 * @throws {@link ServiceQuotaExceededException} (client fault)
 *  <p>You have reached a quota for your bot. </p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>Your request rate is too high. Reduce the frequency of
 *          requests.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>One of the input parameters in your request isn't valid. Check the
 *          parameters and try your request again.</p>
 *
 * @throws {@link LexModelsV2ServiceException}
 * <p>Base exception class for all service exceptions from LexModelsV2 service.</p>
 *
 * @public
 */
export declare class DescribeBotReplicaCommand extends DescribeBotReplicaCommand_base {
}
