import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { LexModelsV2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../LexModelsV2Client";
import { ListBotLocalesRequest, ListBotLocalesResponse } from "../models/models_1";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListBotLocalesCommand}.
 */
export interface ListBotLocalesCommandInput extends ListBotLocalesRequest {
}
/**
 * @public
 *
 * The output of {@link ListBotLocalesCommand}.
 */
export interface ListBotLocalesCommandOutput extends ListBotLocalesResponse, __MetadataBearer {
}
declare const ListBotLocalesCommand_base: {
    new (input: ListBotLocalesCommandInput): import("@smithy/smithy-client").CommandImpl<ListBotLocalesCommandInput, ListBotLocalesCommandOutput, LexModelsV2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: ListBotLocalesCommandInput): import("@smithy/smithy-client").CommandImpl<ListBotLocalesCommandInput, ListBotLocalesCommandOutput, LexModelsV2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Gets a list of locales for the specified bot.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { LexModelsV2Client, ListBotLocalesCommand } from "@aws-sdk/client-lex-models-v2"; // ES Modules import
 * // const { LexModelsV2Client, ListBotLocalesCommand } = require("@aws-sdk/client-lex-models-v2"); // CommonJS import
 * const client = new LexModelsV2Client(config);
 * const input = { // ListBotLocalesRequest
 *   botId: "STRING_VALUE", // required
 *   botVersion: "STRING_VALUE", // required
 *   sortBy: { // BotLocaleSortBy
 *     attribute: "BotLocaleName", // required
 *     order: "Ascending" || "Descending", // required
 *   },
 *   filters: [ // BotLocaleFilters
 *     { // BotLocaleFilter
 *       name: "BotLocaleName", // required
 *       values: [ // FilterValues // required
 *         "STRING_VALUE",
 *       ],
 *       operator: "CO" || "EQ", // required
 *     },
 *   ],
 *   maxResults: Number("int"),
 *   nextToken: "STRING_VALUE",
 * };
 * const command = new ListBotLocalesCommand(input);
 * const response = await client.send(command);
 * // { // ListBotLocalesResponse
 * //   botId: "STRING_VALUE",
 * //   botVersion: "STRING_VALUE",
 * //   nextToken: "STRING_VALUE",
 * //   botLocaleSummaries: [ // BotLocaleSummaryList
 * //     { // BotLocaleSummary
 * //       localeId: "STRING_VALUE",
 * //       localeName: "STRING_VALUE",
 * //       description: "STRING_VALUE",
 * //       botLocaleStatus: "Creating" || "Building" || "Built" || "ReadyExpressTesting" || "Failed" || "Deleting" || "NotBuilt" || "Importing" || "Processing",
 * //       lastUpdatedDateTime: new Date("TIMESTAMP"),
 * //       lastBuildSubmittedDateTime: new Date("TIMESTAMP"),
 * //     },
 * //   ],
 * // };
 *
 * ```
 *
 * @param ListBotLocalesCommandInput - {@link ListBotLocalesCommandInput}
 * @returns {@link ListBotLocalesCommandOutput}
 * @see {@link ListBotLocalesCommandInput} for command's `input` shape.
 * @see {@link ListBotLocalesCommandOutput} for command's `response` shape.
 * @see {@link LexModelsV2ClientResolvedConfig | config} for LexModelsV2Client's `config` shape.
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>The service encountered an unexpected condition. Try your request
 *          again.</p>
 *
 * @throws {@link ServiceQuotaExceededException} (client fault)
 *  <p>You have reached a quota for your bot. </p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>Your request rate is too high. Reduce the frequency of
 *          requests.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>One of the input parameters in your request isn't valid. Check the
 *          parameters and try your request again.</p>
 *
 * @throws {@link LexModelsV2ServiceException}
 * <p>Base exception class for all service exceptions from LexModelsV2 service.</p>
 *
 * @public
 */
export declare class ListBotLocalesCommand extends ListBotLocalesCommand_base {
}
